@@ -2,12 +2,13 @@ exports.config = {
   allScriptsTimeout: 11000,
 
   specs: [
-    'build/docs/ptore2e/**/*.js',
+    'build/docs/ptore2e/**/*jqlite_test.js',
     'test/e2e/docsAppE2E.js'
   ],
 
   capabilities: {
-    'browserName': 'chrome'
+    'browserName': 'chrome',
+    'name': 'Angular E2E: jqlite'
   },
 
   baseUrl: 'http://localhost:8000/build/docs/',
